//   $Id: kvi_chng.cpp,v 1.5 1998/09/28 13:03:09 pragma Exp $
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1998 Szymon Stefanek (stefanek@tin.it)
//
//   This program is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Library General Public
//   License as published by the Free Software Foundation; either
//   version 2 of the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Library General Public License for more details.
//
//   You should have received a copy of the GNU Library General Public License
//   along with this library; see the file COPYING.LIB.  If not, write to
//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA 02111-1307, USA.
//
//#define _KVI_DEBUG_CLASS_NAME_ "KviChangers"

#include "kvi_macros.h"
#include "kvi_chng.h"
#include "kvi_debug.h"
#include "kvi_app.h"

#include <kfontdialog.h>


//============ KviNewColorChanger ============//

KviNewColorChanger::KviNewColorChanger(QTabDialog *dialog,QWidget *parent,const char *text,QColor *color)
:QWidget(parent,"KviNewColorChangerClass")
{
	_debug_entertrace("KviNewColorChanger");
	m_lpColor    =color;
	m_lpColorBtn =new KColorButton((*color),this);
	m_lpLabel    =new QLabel(text,this);
	connect(dialog,SIGNAL(applyButtonPressed()),this,SLOT(applySlot()));
	_debug_leavetrace("KviNewColorChanger");
}

//============ ~KviNewColorChanger ============//

KviNewColorChanger::~KviNewColorChanger()
{
	_debug_entertrace("~KviNewColorChanger");
	_debug_leavetrace("~KviNewColorChanger");
}

//============ applySlot ============//

void KviNewColorChanger::applySlot()
{
	_debug_entertrace("applySlot");
	(*m_lpColor)=m_lpColorBtn->color();
	_debug_leavetrace("applySlot");
}

//============ resizeEvent ============//

void KviNewColorChanger::resizeEvent(QResizeEvent *)
{
	_debug_entertrace("resizeEvent");
	m_lpLabel->setGeometry(0,0,width()-100,height());
	m_lpColorBtn->setGeometry(width()-95,0,95,height());
	_debug_leavetrace("resizeEvent");
}

//============ sizeHint ============//

QSize KviNewColorChanger::sizeHint() const
{
	_debug_entertrace("sizeHint");
	QSize ret=m_lpLabel->sizeHint();
	ret.setWidth(ret.width()+100);
	if(ret.height() < 25)ret.setHeight(25);
	_debug_leavetrace("sizeHint");
	return ret;
}


//============ KviNewPixmapChanger ============//

KviNewPixmapChanger::KviNewPixmapChanger(QTabDialog *dialog,QWidget *parent,const char *text,QString *filename,QPixmap *pixmap)
:QWidget(parent,"KviNewPixmapChangerClass")
{
	_debug_entertrace("KviNewPixmapChanger");
	m_lpFileName =filename;
	m_lpPixmap   =pixmap;
	m_lpBox      =new QListBox(this);
	m_lpLabel    =new QLabel(text,this);
	m_lpPreview  =new QLabel(this);
	m_lpPreview->setFrameStyle(QFrame::Panel | QFrame::Sunken);
	m_lpIL=_macro_kviIconLoader;
	QStrList *lpDirList=m_lpIL->getDirList();
	const char *szDir=0;
	uint idx_last=0;
	m_lpBox->insertItem(i18n("[__none__]"));
	m_lpBox->setCurrentItem(0);
	int index=1;
	for(szDir=lpDirList->first();szDir;szDir=lpDirList->next()){
		QDir theDir(szDir,"*.gif");
		int cnt=theDir.count();
		for(int i=0;i<cnt;i++){
			m_lpBox->insertItem(theDir[i]);	
			if(strcmp(theDir[i],filename->data())==0)idx_last=index;
			index++;
		}
	}
	for(szDir=lpDirList->first();szDir;szDir=lpDirList->next()){
		QDir theDir(szDir,"*.xpm");
		int cnt=theDir.count();
		for(int i=0;i<cnt;i++){
			m_lpBox->insertItem(theDir[i]);	
			if(strcmp(theDir[i],filename->data())==0)idx_last=index;
			index++;
		}
	}
	for(szDir=lpDirList->first();szDir;szDir=lpDirList->next()){
		QDir theDir(szDir,"*.ppm");
		int cnt=theDir.count();
		for(int i=0;i<cnt;i++){
			m_lpBox->insertItem(theDir[i]);	
			if(strcmp(theDir[i],filename->data())==0)idx_last=index;
			index++;
		}
	}
	m_lpBox->setCurrentItem(idx_last);
	if(!pixmap->isNull())m_lpPreview->setBackgroundPixmap(*pixmap);
	connect(dialog,SIGNAL(applyButtonPressed()),this,SLOT(applySlot()));
	connect(m_lpBox,SIGNAL(highlighted(int)),this,SLOT(selectionChanged(int)));
	_debug_leavetrace("KviNewPixmapChanger");
}

//============ ~KviNewPixmapChanger ============//

KviNewPixmapChanger::~KviNewPixmapChanger()
{
	_debug_entertrace("~KviNewPixmapChanger");
	_debug_leavetrace("~KviNewPixmapChanger");
}

//============ applySlot ============//

void KviNewPixmapChanger::applySlot()
{
	_debug_entertrace("applySlot");
	const char *szFile=m_lpBox->text(m_lpBox->currentItem());
	if(strcmp(szFile,i18n("[__none__]"))==0){
		m_lpPixmap->resize(0,0);
		(*m_lpFileName)=i18n("[__none__]");
	} else {
		QPixmap pix=m_lpIL->loadIcon(szFile);
		if(!pix.isNull()){
			(*m_lpPixmap)=pix;
			(*m_lpFileName)=szFile;
		} else {
			m_lpPixmap->resize(0,0);
			(*m_lpFileName)=i18n("[__none__]");
		}
	}
	_debug_leavetrace("applySlot");
}

//============ selectionChanged ============//

void KviNewPixmapChanger::selectionChanged(int idx)
{
	_debug_entertrace("selectionChanged");
	const char *szFile=m_lpBox->text(idx);
	if(strcmp(szFile,i18n("[__none__]"))==0){
		m_lpPreview->setBackgroundColor(QColor(80,80,80));
	} else {
		QPixmap pix=m_lpIL->loadIcon(szFile);
		if(!pix.isNull()){
			m_lpPreview->setBackgroundPixmap(pix);
		}
	}
	m_lpPreview->repaint();
	_debug_leavetrace("selectionChanged");
}


//============ resizeEvent ============//

void KviNewPixmapChanger::resizeEvent(QResizeEvent *)
{
	_debug_entertrace("resizeEvent");
	int h=m_lpLabel->sizeHint().height();
	m_lpLabel->setGeometry(0,0,width(),h);
	m_lpBox->setGeometry(0,h+1,(width()/2)-5,height()-(h+1));
	m_lpPreview->setGeometry((width()/2)+3,h+1,(width()/2)-5,height()-(h+1));
	_debug_leavetrace("resizeEvent");
}

//============ sizeHint ============//

QSize KviNewPixmapChanger::sizeHint() const
{
	_debug_entertrace("sizeHint");
	QSize ret=m_lpLabel->sizeHint();
	ret.setHeight(ret.height()+100); //at least 100 pixels height for preview
	_debug_leavetrace("sizeHint");
	return ret;
}


//============ KviNewFontChanger ============//

KviNewFontChanger::KviNewFontChanger(QTabDialog *dialog,QWidget *parent,const char *text,QFont *font)
:QWidget(parent,"KviNewFontChangerClass")
{
	_debug_entertrace("KviNewFontChanger");
	m_lpFont=font;
//	m_lpParent=dialog;
	m_lpButton=new QPushButton(i18n("Sample"),this);
	m_lpButton->setFont(*font);
	m_lpButton->repaint();
	connect(m_lpButton,SIGNAL(clicked()),this,SLOT(buttonPressed()));
	m_lpLabel=new QLabel(text,this);
	connect(dialog,SIGNAL(applyButtonPressed()),this,SLOT(applySlot()));
	_debug_leavetrace("KviNewFontChanger");
}

//============ ~KviNewFontChanger ============//

KviNewFontChanger::~KviNewFontChanger()
{
	_debug_entertrace("~KviNewFontChanger");
	_debug_leavetrace("~KviNewFontChanger");
}

//============ applySlot ============//

void KviNewFontChanger::applySlot()
{
	_debug_entertrace("applySlot");
	(*m_lpFont)=m_lpButton->font();
	_debug_leavetrace("applySlot");
}

//============ buttonPressed ============//

void KviNewFontChanger::buttonPressed()
{
	_debug_entertrace("buttonPressed");
	KFontDialog aDialog(this,"KviFontChanger",true);
//	m_lpOldFocusProxy=m_lpParent->focusProxy();
//	m_lpParent->setFocusProxy(&aDialog);
	aDialog.setFont(m_lpButton->font());
	if(aDialog.exec()==QDialog::Accepted){
		m_lpButton->setFont(aDialog.font());
		m_lpButton->repaint();
	}
//	m_lpParent->setFocusProxy(m_lpOldFocusProxy);
	_debug_leavetrace("buttonPressed");
}

//============ resizeEvent ============//

void KviNewFontChanger::resizeEvent(QResizeEvent *)
{
	_debug_entertrace("resizeEvent");
	m_lpLabel->setGeometry(0,0,width()-100,height());
	m_lpButton->setGeometry(width()-95,0,95,height());
	_debug_leavetrace("resizeEvent");
}

//============ sizeHint ============//

QSize KviNewFontChanger::sizeHint() const
{
	_debug_entertrace("sizeHint");
	QSize ret=m_lpLabel->sizeHint();
	ret.setWidth(ret.width()+100);
	if(ret.height() < 25)ret.setHeight(25);
	_debug_leavetrace("sizeHint");
	return ret;
}

//********************OLD CLASSES : To be discarded********************//

KviBoolChanger::KviBoolChanger(QTabDialog *lpDlg,QWidget *parent,
									int x,int y,int w,int h,
									const char *szText,bool *lpBool)
			:QCheckBox(szText,parent){
	m_lpBool=lpBool;
	setGeometry(x,y,w,h);
	setChecked((*m_lpBool));
	connect(lpDlg,SIGNAL(applyButtonPressed()),this,SLOT(applySlot()));
}
KviBoolChanger::~KviBoolChanger(){
}

void KviBoolChanger::applySlot(){
	(*m_lpBool)=isChecked();
}


#include "m_kvi_chng.moc"

//
// $Log: kvi_chng.cpp,v $
// Revision 1.5  1998/09/28 13:03:09  pragma
// Moved to geometry management.
// New Changer classes.
//
//
