//   $Id: kvi_optdlg.cpp,v 1.10 1998/10/06 14:42:39 pragma Exp $
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1998 Szymon Stefanek (stefanek@tin.it)
//
//   This program is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Library General Public
//   License as published by the Free Software Foundation; either
//   version 2 of the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Library General Public License for more details.
//
//   You should have received a copy of the GNU Library General Public License
//   along with this program; see the file COPYING.  If not, write to
//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA 02111-1307, USA.
//

#define _KVI_DEBUG_CLASS_NAME_ "KviOptDialog"

#include "kvi_macros.h"
#include "kvi_optdlg.h"
#include "kvi_translate.h"
#include "kvi_frame.h"
#include "kvi_app.h"
#include "kvi_opt.h"
#include "kvi_chng.h"
#include "kvi_debug.h"

//#include <kfiledialog.h>
#include <kseparator.h>
#include <kmsgbox.h>

KviOptDialog::KviOptDialog(KviFrame *lpParent,KviOptions *lpOpt):QTabDialog(lpParent,"Options dialog",true)
{
	m_lpOpt=lpOpt;
	m_lpFrm=lpParent;

	resize(420,250);

	setCaption(i18n("Misc options"));

	//+++++++++++++++++++
	//	Messages tab
	//+++++++++++++++++++

	lpMsgTab=new QWidget(this);

	lpCaption   = new QLineEdit(lpMsgTab);
	lpQuit      = new QLineEdit(lpMsgTab);
	lpPart      = new QLineEdit(lpMsgTab);
	lpKick      = new QLineEdit(lpMsgTab);
	lpAway      = new QLineEdit(lpMsgTab);
	lpFinger    = new QLineEdit(lpMsgTab);
	lpUserInfo  = new QLineEdit(lpMsgTab);
	lpScript    = new QLineEdit(lpMsgTab);

	QLabel *lpM1 = new QLabel(i18n("Caption text"),lpMsgTab);
	QLabel *lpM2 = new QLabel(i18n("Quit message"),lpMsgTab);
	QLabel *lpM3 = new QLabel(i18n("Part message"),lpMsgTab);
	QLabel *lpM4 = new QLabel(i18n("Kick message"),lpMsgTab);
	QLabel *lpM5 = new QLabel(i18n("Away message"),lpMsgTab);
	QLabel *lpM6 = new QLabel(i18n("Finger reply"),lpMsgTab);
	QLabel *lpM7 = new QLabel(i18n("Userinfo reply"),lpMsgTab);
	QLabel *lpM8 = new QLabel(i18n("Script version"),lpMsgTab);

	lpM1->setGeometry(10,20,95,26);
	lpM2->setGeometry(10,50,95,26);
	lpM3->setGeometry(10,80,95,26);
	lpM4->setGeometry(10,110,95,26);
	lpM5->setGeometry(10,140,95,26);
	lpM6->setGeometry(10,170,95,26);
	lpM7->setGeometry(10,200,95,26);
	lpM8->setGeometry(10,230,95,26);

	lpCaption->setText(m_lpOpt->szCaption.data());
	lpQuit->setText(m_lpOpt->szQuitMsg.data());
	lpPart->setText(m_lpOpt->szPartMsg.data());
	lpKick->setText(m_lpOpt->szKickMsg.data());
	lpAway->setText(m_lpOpt->szAwayMsg.data());
	lpFinger->setText(m_lpOpt->szFinger.data());
	lpUserInfo->setText(m_lpOpt->szUserInfo.data());
	lpScript->setText(m_lpOpt->szScriptVer.data());

	lpCaption->setGeometry(110,20,365,26);
	lpQuit->setGeometry(110,50,365,26);
	lpPart->setGeometry(110,80,365,26);
	lpKick->setGeometry(110,110,365,26);
	lpAway->setGeometry(110,140,365,26);
	lpFinger->setGeometry(110,170,365,26);
	lpUserInfo->setGeometry(110,200,365,26);
	lpScript->setGeometry(110,230,365,26);

	//++++++++++++++++++
	//	DCC Tab
	//++++++++++++++++++

	lpDCCTab=new QWidget(this);

	lpAutoChat    = new KviBoolChanger(this,lpDCCTab,240,10,220,26,i18n("Auto accept DCC Chat"),&(m_lpOpt->bAutoAcceptDCCChat));
	lpAutoSend    = new KviBoolChanger(this,lpDCCTab,240,37,220,26,i18n("Auto accept DCC Send"),&(m_lpOpt->bAutoAcceptDCCSend));
	lpAutoVoice   = new KviBoolChanger(this,lpDCCTab,240,64,220,26,i18n("Auto accept DCC Voice"),&(m_lpOpt->bAutoAcceptDCCVoice));
	lpIgnoreChat  = new KviBoolChanger(this,lpDCCTab,10,10,220,26,i18n("Ignore DCC Chat"),&(m_lpOpt->bIgnoreDCCChat));
	lpIgnoreSend  = new KviBoolChanger(this,lpDCCTab,10,37,220,26,i18n("Ignore DCC Send"),&(m_lpOpt->bIgnoreDCCSend));
	lpIgnoreVoice = new KviBoolChanger(this,lpDCCTab,10,64,220,26,i18n("Ignore DCC Voice"),&(m_lpOpt->bIgnoreDCCVoice));
	lpAutoClose   = new KviBoolChanger(this,lpDCCTab,240,91,220,26,i18n("Auto close DCC Send window"),&(m_lpOpt->bAutoCloseDCCChatOnSuccess));
	lpAutoMinimize= new KviBoolChanger(this,lpDCCTab,10,91,220,26,i18n("Minimize DCC Send window"),&(m_lpOpt->bMinimizeDCCSend));
	lpPacket=new KIntegerLine(lpDCCTab);
	lpTimeout=new KIntegerLine(lpDCCTab);
	QLabel *lp8=new QLabel(i18n("Dcc Send packet (bytes)[64-4096]"),lpDCCTab);
	QLabel *lp9=new QLabel(i18n("Dcc Send/Chat timeout (sec.)[>10]"),lpDCCTab);
	lp8->setGeometry(10,118,220,26);
	lp9->setGeometry(10,145,220,26);
	lpPacket->setGeometry(240,118,235,26);
	lpTimeout->setGeometry(240,145,235,26);

	connect(lpIgnoreChat,SIGNAL(toggled(bool)),this,SLOT(chatIgnore(bool)));
	connect(lpIgnoreSend,SIGNAL(toggled(bool)),this,SLOT(sendIgnore(bool)));
	connect(lpIgnoreVoice,SIGNAL(toggled(bool)),this,SLOT(voiceIgnore(bool)));

	lpAutoChat->setEnabled(!m_lpOpt->bIgnoreDCCChat);
	lpAutoSend->setEnabled(!m_lpOpt->bIgnoreDCCSend);
	lpAutoVoice->setEnabled(!m_lpOpt->bIgnoreDCCVoice);

	lpPacket->setValue(m_lpOpt->iDCCSendPacketSize);
	lpTimeout->setValue(m_lpOpt->iDCCCHATTimeout);

	lpMotd    = new QMultiLineEdit(lpDCCTab);
	if(!m_lpOpt->lpListDccMotd->isEmpty()){
		const char *szS=0;
		for(szS=m_lpOpt->lpListDccMotd->first();szS;szS=m_lpOpt->lpListDccMotd->next()){
			lpMotd->append(szS);
		}
	}

	lpUseFastSend=new KviBoolChanger(this,lpDCCTab,10,171,220,26,i18n("Use DCC fast send with"),&(m_lpOpt->bUseFastSend));
	lpFSPacketSize   =new QComboBox(lpDCCTab);
	lpFSPacketsPerSec=new QComboBox(lpDCCTab);
	lpFSPacketsPerSec->setGeometry(240,171,40,26);
	QLabel *lpFS1=new QLabel(i18n("pkt/sec of"),lpDCCTab);
	lpFS1->setGeometry(285,171,70,26);
	lpFSPacketSize->setGeometry(360,171,60,26);
	QLabel *lpFS2=new QLabel(i18n("bytes"),lpDCCTab);
	lpFS2->setGeometry(425,171,40,26);

	connect(lpUseFastSend,SIGNAL(toggled(bool)),lpFSPacketSize,SLOT(setEnabled(bool)));
	connect(lpUseFastSend,SIGNAL(toggled(bool)),lpFSPacketsPerSec,SLOT(setEnabled(bool)));
	connect(lpUseFastSend,SIGNAL(toggled(bool)),lpFS1,SLOT(setEnabled(bool)));
	connect(lpUseFastSend,SIGNAL(toggled(bool)),lpFS2,SLOT(setEnabled(bool)));

	lpFSPacketsPerSec->insertItem("1");
	lpFSPacketsPerSec->insertItem("2");
	lpFSPacketsPerSec->insertItem("3");
	lpFSPacketsPerSec->insertItem("4");
	lpFSPacketsPerSec->insertItem("5");
	lpFSPacketsPerSec->insertItem("6");
	lpFSPacketsPerSec->insertItem("7");
	lpFSPacketsPerSec->insertItem("8");
	lpFSPacketsPerSec->insertItem("9");
	lpFSPacketsPerSec->insertItem("10");
	lpFSPacketsPerSec->insertItem("11!");
	lpFSPacketsPerSec->insertItem("12!");
	lpFSPacketsPerSec->insertItem("13!");
	lpFSPacketsPerSec->insertItem("14!");
	lpFSPacketsPerSec->insertItem("15!");
	lpFSPacketsPerSec->insertItem("16!");
	lpFSPacketsPerSec->insertItem("17!");
	lpFSPacketsPerSec->insertItem("18!");
	lpFSPacketsPerSec->insertItem("19!");
	lpFSPacketsPerSec->insertItem("20!");

	lpFSPacketSize->insertItem("64");
	lpFSPacketSize->insertItem("128");
	lpFSPacketSize->insertItem("256");
	lpFSPacketSize->insertItem("512");
	lpFSPacketSize->insertItem("768");
	lpFSPacketSize->insertItem("1024");
	lpFSPacketSize->insertItem("1536");
	lpFSPacketSize->insertItem("2048");
	lpFSPacketSize->insertItem("2560");
	lpFSPacketSize->insertItem("3072");
	lpFSPacketSize->insertItem("4096");

	if((m_lpOpt->iFSPacketsPerSec<1)||(m_lpOpt->iFSPacketsPerSec>20))m_lpOpt->iFSPacketsPerSec=2;
	switch(m_lpOpt->iFSPacketSize){
		case 64:
			lpFSPacketSize->setCurrentItem(0);
			break;
		case 128:
			lpFSPacketSize->setCurrentItem(1);
			break;
		case 256:
			lpFSPacketSize->setCurrentItem(2);
			break;
		case 512:
			lpFSPacketSize->setCurrentItem(3);
			break;
		case 768:
			lpFSPacketSize->setCurrentItem(4);
			break;
		case 1024:
			lpFSPacketSize->setCurrentItem(5);
			break;
		case 1536:
			lpFSPacketSize->setCurrentItem(6);
			break;
		case 2048:
			lpFSPacketSize->setCurrentItem(7);
			break;
		case 2560:
			lpFSPacketSize->setCurrentItem(8);
			break;
		case 3072:
			lpFSPacketSize->setCurrentItem(9);
			break;
		case 4096:
			lpFSPacketSize->setCurrentItem(10);
			break;
		default:
			lpFSPacketSize->setCurrentItem(3);
			m_lpOpt->iFSPacketSize=512;
			break;
	}
	lpFSPacketsPerSec->setCurrentItem(m_lpOpt->iFSPacketsPerSec-1);
	lpFSPacketSize->setEnabled(m_lpOpt->bUseFastSend);
	lpFSPacketsPerSec->setEnabled(m_lpOpt->bUseFastSend);
	lpFS1->setEnabled(m_lpOpt->bUseFastSend);
	lpFS2->setEnabled(m_lpOpt->bUseFastSend);

	lpMotd->setGeometry(10,254,465,66);

	lpShowMotdOnInDcc = new KviBoolChanger(this,lpDCCTab,10,228,220,26,i18n("Send MOTD on Incoming DCC Chat"),&(m_lpOpt->bShowMotdOnInDcc));
	lpShowMotdOnOutDcc= new KviBoolChanger(this,lpDCCTab,240,228,220,26,i18n("Send MOTD on Outgoing DCC Chat"),&(m_lpOpt->bShowMotdOnOutDcc));
	connect(lpShowMotdOnInDcc,SIGNAL(toggled(bool)),this,SLOT(enableMotd(bool)));
	connect(lpShowMotdOnOutDcc,SIGNAL(toggled(bool)),this,SLOT(enableMotd(bool)));

	QLabel *lpMotdLabel=new QLabel(i18n("Message of the day for the DCC Chat server (MOTD):"),lpDCCTab);
	KSeparator *lpSep1=new KSeparator(KSeparator::HLine,lpDCCTab);
	lpSep1->setGeometry(10,198,465,4);
	lpMotdLabel->setGeometry(10,202,405,26);
	lpMotd->setEnabled(m_lpOpt->bShowMotdOnInDcc || m_lpOpt->bShowMotdOnOutDcc);

	//++++++++++++++++++++++++++++++++
	// Translation & URL catcher tab
	//++++++++++++++++++++++++++++++++

	lpTrnTab=new QWidget(this);

	// translation

	QString szText=i18n("Translation map file : ");
	szText+=m_lpOpt->szTranslationFile.data();

	lpUseTran   =new KviBoolChanger(this,lpTrnTab,10,20,465,26,i18n("Use charset translation (You need to set the correct font too)"),
									&(m_lpOpt->bUseTranslation));
	lpTranFile  =new QLabel(szText.data(),lpTrnTab);
	lpChooseFile=new QPushButton(i18n("Choose translation file..."),lpTrnTab);
	lpNotTranDCC=new KviBoolChanger(this,lpTrnTab,10,110,465,26,i18n("Send DCC Chat outgoing data in local charset"),
									&(m_lpOpt->bNotTranslateDCC));

	connect(lpUseTran,SIGNAL(toggled(bool)),lpTranFile,SLOT(setEnabled(bool)));
	connect(lpUseTran,SIGNAL(toggled(bool)),lpChooseFile,SLOT(setEnabled(bool)));
	connect(lpChooseFile,SIGNAL(clicked()),this,SLOT(chooseTranslationFile()));
	connect(lpUseTran,SIGNAL(toggled(bool)),lpNotTranDCC,SLOT(setEnabled(bool)));

	lpChooseFile->setGeometry(10,80,465,26);
	lpTranFile->setGeometry(10,50,465,26);

	lpChooseFile->setEnabled(m_lpOpt->bUseTranslation);
	lpTranFile->setEnabled(m_lpOpt->bUseTranslation);
	lpNotTranDCC->setEnabled(m_lpOpt->bUseTranslation);

	// separator
	
	KSeparator *lpSep3 = new KSeparator(KSeparator::HLine,lpTrnTab);
	lpSep3->setGeometry(10,140,465,4);

	//url catcher

	lpBrowserOnUrl = new KviBoolChanger(this,lpTrnTab,10,150,465,26,i18n("Run browser on url double click"),(&m_lpOpt->bRunBrowserOnUrl));
	lpUseNetscape  = new KviBoolChanger(this,lpTrnTab,10,180,465,26,i18n("Use netscape remote control instead of running the program below")
											,(&m_lpOpt->bUseNetscape));
 	lpBrowserCmd   = new QLineEdit(lpTrnTab);
	QLabel *lpBrw1 = new QLabel(i18n("Browser command line (use % as file name)"),lpTrnTab);
	lpHighlightUrl = new KviBoolChanger(this,lpTrnTab,10,280,400,26,i18n("Highlight urls using the mIrc color (0-15)")
											,(&m_lpOpt->bHighlightUrl));
	lpUrlColor     = new KIntegerLine(lpTrnTab);
	KSeparator *lpSep4 = new KSeparator(KSeparator::HLine,lpTrnTab);

	connect(lpBrowserOnUrl,SIGNAL(toggled(bool)),lpUseNetscape,SLOT(setEnabled(bool)));
	connect(lpBrowserOnUrl,SIGNAL(toggled(bool)),lpBrw1,SLOT(setEnabled(bool)));
	connect(lpBrowserOnUrl,SIGNAL(toggled(bool)),lpBrowserCmd,SLOT(setEnabled(bool)));	
	connect(lpHighlightUrl,SIGNAL(toggled(bool)),lpUrlColor,SLOT(setEnabled(bool)));

	lpUseNetscape->setEnabled(m_lpOpt->bRunBrowserOnUrl);
	lpBrw1->setEnabled(m_lpOpt->bRunBrowserOnUrl);
	lpBrowserCmd->setEnabled(m_lpOpt->bRunBrowserOnUrl);
	lpUrlColor->setEnabled(m_lpOpt->bHighlightUrl);

	lpBrw1->setGeometry(10,210,465,26);
	lpBrowserCmd->setGeometry(10,240,465,26);
	lpUrlColor->setGeometry(420,280,55,26);
	lpSep4->setGeometry(10,270,465,4);

	lpBrowserCmd->setText(m_lpOpt->szBrowserCmdLine.data());
	lpUrlColor->setValue((int)m_lpOpt->urlHighlightForeColor);



	lpMisTab=new QWidget(this);

	lpIp=new QLineEdit(lpMisTab);
	QLabel *lp6=new QLabel(i18n("Local IP (for multiip machines)"),lpMisTab);
	lp6->setGeometry(10,20,210,26);
	lpIp->setGeometry(225,20,250,26);
	lpIp->setText(m_lpOpt->szLocalIp.data());
	
	lpPrfx=new QLineEdit(lpMisTab);
	QLabel *lp7=new QLabel(i18n("Personal command prefix"),lpMisTab);
	lp7->setGeometry(10,50,180,26);
	lpPrfx->setGeometry(225,50,250,26);
	QString szPr="";
	szPr+=m_lpOpt->chPersonalCommandPrefix;
	lpPrfx->setText(szPr.data());
	lpPrfx->setMaxLength(1);

	QLabel *lp10=new QLabel(i18n("Allow max"),lpMisTab);
	lpMaxCTCP   =new KIntegerLine(lpMisTab);
	QLabel *lp11=new QLabel(i18n("CTCP's in"),lpMisTab);
	lpSecCTCP   =new KIntegerLine(lpMisTab);
	QLabel *lp12=new QLabel(i18n("seconds (0=ignore)"),lpMisTab);

	lp10->setGeometry(10,80,60,26);
	lpMaxCTCP->setGeometry(75,80,40,26);
	lp11->setGeometry(120,80,85,26);
	lpSecCTCP->setGeometry(225,80,40,26);
	lp12->setGeometry(275,80,110,26);

	lpMaxCTCP->setValue(m_lpOpt->iMaxCTCP);
	lpSecCTCP->setValue(m_lpOpt->iTimerCTCP);

	lpUserList=new KviBoolChanger(this,lpMisTab,10,110,213,26,i18n("Enable user list update every"),&(m_lpOpt->bEnableUserListUpdate));
	lpUserTime=new KIntegerLine(lpMisTab);
	lpUserTime->setGeometry(225,110,40,26);
	lpUserTime->setValue(m_lpOpt->iUserListUpdateTime);

	connect(lpUserList,SIGNAL(toggled(bool)),lpUserTime,SLOT(setEnabled(bool)));

	lpUserTime->setEnabled(lpUserList->isChecked());
	QLabel *lp13=new QLabel(i18n("seconds"),lpMisTab);
	lp13->setGeometry(270,110,110,26);

	KSeparator *lpSep5 = new KSeparator(KSeparator::HLine,lpMisTab);
	lpSep5->setGeometry(10,140,465,4);

	QLabel *lpMass1      = new QLabel(i18n("Event_OnMassDeop    fires after"),lpMisTab);
	QLabel *lpMass2      = new QLabel(i18n("Event_OnMassOp      fires after"),lpMisTab);
	QLabel *lpMass3      = new QLabel(i18n("Event_OnMassKick    fires after"),lpMisTab);
	QLabel *lpMass4      = new QLabel(i18n("Event_OnMassBan     fires after"),lpMisTab);
	QLabel *lpMass5      = new QLabel(i18n("Event_OnPublicFlood fires after"),lpMisTab);
	QLabel *lpMass1a     = new QLabel(i18n("deop(s) in"),lpMisTab);
	QLabel *lpMass2a     = new QLabel(i18n("op(s) in"),lpMisTab);
	QLabel *lpMass3a     = new QLabel(i18n("kick(s) in"),lpMisTab);
	QLabel *lpMass4a     = new QLabel(i18n("ban(s) in"),lpMisTab);
	QLabel *lpMass5a     = new QLabel(i18n("line(s) in"),lpMisTab);
	QLabel *lpMass1b     = new QLabel(i18n("second(s)"),lpMisTab);
	QLabel *lpMass2b     = new QLabel(i18n("second(s)"),lpMisTab);
	QLabel *lpMass3b     = new QLabel(i18n("second(s)"),lpMisTab);
	QLabel *lpMass4b     = new QLabel(i18n("second(s)"),lpMisTab);
	QLabel *lpMass5b     = new QLabel(i18n("second(s)"),lpMisTab);
	lpMassDeopTime       = new KIntegerLine(lpMisTab);
	lpMassOpTime         = new KIntegerLine(lpMisTab);
	lpMassKickTime       = new KIntegerLine(lpMisTab);
	lpMassBanTime        = new KIntegerLine(lpMisTab);
	lpPublicFloodTime    = new KIntegerLine(lpMisTab);
	lpMassDeopDeadline   = new KIntegerLine(lpMisTab);
	lpMassOpDeadline     = new KIntegerLine(lpMisTab);
	lpMassKickDeadline   = new KIntegerLine(lpMisTab);
	lpMassBanDeadline    = new KIntegerLine(lpMisTab);
	lpPublicFloodDeadline= new KIntegerLine(lpMisTab);

	lpMass1->setGeometry(10,150,210,26);
	lpMassDeopDeadline->setGeometry(225,150,40,26);
	lpMass1a->setGeometry(270,150,80,26);
	lpMassDeopTime->setGeometry(355,150,40,26);
	lpMass1b->setGeometry(400,150,65,26);

	lpMass2->setGeometry(10,180,210,26);
	lpMassOpDeadline->setGeometry(225,180,40,26);
	lpMass2a->setGeometry(270,180,80,26);
	lpMassOpTime->setGeometry(355,180,40,26);
	lpMass2b->setGeometry(400,180,65,26);

	lpMass3->setGeometry(10,210,210,26);
	lpMassKickDeadline->setGeometry(225,210,40,26);
	lpMass3a->setGeometry(270,210,80,26);
	lpMassKickTime->setGeometry(355,210,40,26);
	lpMass3b->setGeometry(400,210,65,26);

	lpMass4->setGeometry(10,240,210,26);
	lpMassBanDeadline->setGeometry(225,240,40,26);
	lpMass4a->setGeometry(270,240,80,26);
	lpMassBanTime->setGeometry(355,240,40,26);
	lpMass4b->setGeometry(400,240,65,26);

	lpMass5->setGeometry(10,270,210,26);
	lpPublicFloodDeadline->setGeometry(225,270,40,26);
	lpMass5a->setGeometry(270,270,80,26);
	lpPublicFloodTime->setGeometry(355,270,40,26);
	lpMass5b->setGeometry(400,270,65,26);

	lpMassDeopDeadline->setValue(m_lpOpt->massDeopDeadline);
	lpMassDeopTime->setValue(m_lpOpt->massDeopTime);
	lpMassOpDeadline->setValue(m_lpOpt->massOpDeadline);
	lpMassOpTime->setValue(m_lpOpt->massOpTime);
	lpMassKickDeadline->setValue(m_lpOpt->massKickDeadline);
	lpMassKickTime->setValue(m_lpOpt->massKickTime);
	lpMassBanDeadline->setValue(m_lpOpt->massBanDeadline);
	lpMassBanTime->setValue(m_lpOpt->massBanTime);
	lpPublicFloodDeadline->setValue(m_lpOpt->publicFloodDeadline);
	lpPublicFloodTime->setValue(m_lpOpt->publicFloodTime);

	lpMixTab=new QWidget(this);

	lpClone             =new KviBoolChanger(this,lpMixTab,10,20,400,24,i18n("Enable clone scan on join"),&(m_lpOpt->bCloneScanOnJoin));
	lpInverseNick       =new KviBoolChanger(this,lpMixTab,10,45,400,24,i18n("Show inverse colored nick in channel messages"),&(m_lpOpt->bInverseNick));
	lpPrefixMsg         =new KviBoolChanger(this,lpMixTab,10,70,400,24,i18n("Prefix channel messages with ':'"),&(m_lpOpt->bPrefixMsg));
	lpAutoRejoin        =new KviBoolChanger(this,lpMixTab,10,95,400,24,i18n("Autorejoin channel when kicked"),&(m_lpOpt->bAutoRejoinOnKick));
	lpShowColorBox      =new KviBoolChanger(this,lpMixTab,10,120,400,24,i18n("Popup color box in the input line on CTRL+K"),(&m_lpOpt->bShowColorBox));
	lpTimestamp         =new KviBoolChanger(this,lpMixTab,10,145,400,24,i18n("Timestamp messages on the output box"),&(m_lpOpt->bTimestamp));
	lpAlignText         =new KviBoolChanger(this,lpMixTab,10,170,400,24,i18n("Align text after a line break"),&(m_lpOpt->bAlignText));
	lpShowPixmaps       =new KviBoolChanger(this,lpMixTab,10,195,400,24,i18n("Show message-images in the output box"),&(m_lpOpt->bShowPixmaps));
	lpAutoJoinOnInvite  =new KviBoolChanger(this,lpMixTab,10,220,400,24,i18n("Auto join channel when invited"),&(m_lpOpt->bAutoJoinOnInvite));
	lpPrivNoticeToActive=new KviBoolChanger(this,lpMixTab,10,245,400,24,i18n("Private notices to active window"),&(m_lpOpt->bPrivNoticeToActive));
	lpCtcpRequestsToActive=new KviBoolChanger(this,lpMixTab,10,270,400,24,i18n("Ctcp requests to active window"),&(m_lpOpt->bCtcpRequestsToActive));
	lpAutoCompletion    =new KviBoolChanger(this,lpMixTab,10,295,400,24,i18n("Auto nick completion ( 'Ni: text->Nick: text')"),(&m_lpOpt->bAutoNickCompletion));

	lpMix4Tab=new QWidget(this);

	lpIdentParsingOff   =new KviBoolChanger(this,lpMix4Tab,10,20,400,24,i18n("Identifiers parsing off by default"),&(m_lpOpt->bIdentParsingOff));
	lpAutoLogChannels   =new KviBoolChanger(this,lpMix4Tab,10,45,400,24,i18n("Auto log channels"),&(m_lpOpt->bAutoLogChannels));
	lpAutoLogQueries    =new KviBoolChanger(this,lpMix4Tab,10,70,400,24,i18n("Auto log queries"),&(m_lpOpt->bAutoLogQueries));
	lpAutoLogChats      =new KviBoolChanger(this,lpMix4Tab,10,95,400,24,i18n("Auto log chats"),&(m_lpOpt->bAutoLogChats));
	lpMinimizeQuery     =new KviBoolChanger(this,lpMix4Tab,10,120,400,24,i18n("Auto minimize query windows"),&(m_lpOpt->bMinimizeQuery));
	lpBeepOnPrivmsg     =new KviBoolChanger(this,lpMix4Tab,10,145,400,24,i18n("Beep on private conversation requests"),&(m_lpOpt->bBeepOnPrivmsg));
	lpBeepOnDCCRequest  =new KviBoolChanger(this,lpMix4Tab,10,170,400,24,i18n("Beep on DCC requests"),&(m_lpOpt->bBeepOnDCCRequest));
	lpBeepOnCTCPRequest =new KviBoolChanger(this,lpMix4Tab,10,195,400,24,i18n("Beep on CTCP requests"),&(m_lpOpt->bBeepOnCTCPRequest));

	lpMix3Tab=new QWidget(this);

	lpListenToCtcpSound=new KviBoolChanger(this,lpMix3Tab,10,20,400,26,i18n("Listen to CTCP sound"),(&m_lpOpt->bListenToCtcpSound));
	lpPlayDefSound     =new KviBoolChanger(this,lpMix3Tab,10,50,400,26,i18n("Play default.wav on Ctcp sound , when file not found"),(&m_lpOpt->bPlayDefSound));
	lpSendSoundRequest =new KviBoolChanger(this,lpMix3Tab,10,80,400,26,i18n("Send !nick <soundname> request on sound file not found"),(&m_lpOpt->bSendSoundRequest));
	lpListenFileRequest=new KviBoolChanger(this,lpMix3Tab,10,110,400,26,i18n("Listen to !nick <soundname> requests."),(&m_lpOpt->bListenToFileRequest));
	lpMaxFileRequests  =new KIntegerLine(lpMix3Tab);
	lpMaxFileRequests->setValue(m_lpOpt->iMaxFileRequests);
	connect(lpListenFileRequest,SIGNAL(toggled(bool)),lpMaxFileRequests,SLOT(setEnabled(bool)));
	lpMaxFileRequests->setGeometry(300,140,175,26);
	QLabel *lpFReq=new QLabel(i18n("Max file requests"),lpMix3Tab);
	lpFReq->setGeometry(10,140,285,26);
	connect(lpListenFileRequest,SIGNAL(toggled(bool)),lpFReq,SLOT(setEnabled(bool)));

	lpAuPlayerCmd  = new QLineEdit(lpMix3Tab);
	lpMidPlayerCmd = new QLineEdit(lpMix3Tab);
	lpMp3PlayerCmd = new QLineEdit(lpMix3Tab);
	lpWavPlayerCmd = new QLineEdit(lpMix3Tab);
	lpExternalAuPlayer  =new KviBoolChanger(this,lpMix3Tab,10,170,285,26,i18n("Au player command line (%=file)"),&(m_lpOpt->bExternalAuPlayer));
	lpExternalMidPlayer =new KviBoolChanger(this,lpMix3Tab,10,200,285,26,i18n("Mid player command line (%=file)"),&(m_lpOpt->bExternalMidPlayer));
	lpExternalMp3Player =new KviBoolChanger(this,lpMix3Tab,10,230,285,26,i18n("Mp3 player command line (%=file)"),&(m_lpOpt->bExternalMp3Player));
	lpExternalWavPlayer =new KviBoolChanger(this,lpMix3Tab,10,260,285,26,i18n("Use external Wav player (%=file)"),&(m_lpOpt->bExternalWavPlayer));
	lpAuPlayerCmd->setGeometry(300,170,175,26);
	lpMidPlayerCmd->setGeometry(300,200,175,26);
	lpMp3PlayerCmd->setGeometry(300,230,175,26);
	lpWavPlayerCmd->setGeometry(300,260,175,26);
	connect(lpExternalAuPlayer,SIGNAL(toggled(bool)),lpAuPlayerCmd,SLOT(setEnabled(bool)));
	connect(lpExternalMidPlayer,SIGNAL(toggled(bool)),lpMidPlayerCmd,SLOT(setEnabled(bool)));
	connect(lpExternalMp3Player,SIGNAL(toggled(bool)),lpMp3PlayerCmd,SLOT(setEnabled(bool)));
	connect(lpExternalWavPlayer,SIGNAL(toggled(bool)),lpWavPlayerCmd,SLOT(setEnabled(bool)));
	lpAuPlayerCmd->setText(m_lpOpt->szAuPlayerCmd.data());
	lpMidPlayerCmd->setText(m_lpOpt->szMidPlayerCmd.data());
	lpMp3PlayerCmd->setText(m_lpOpt->szMp3PlayerCmd.data());
	lpWavPlayerCmd->setText(m_lpOpt->szWavPlayerCmd.data());
	lpAuPlayerCmd->setEnabled(m_lpOpt->bExternalAuPlayer);
	lpMidPlayerCmd->setEnabled(m_lpOpt->bExternalMidPlayer);
	lpMp3PlayerCmd->setEnabled(m_lpOpt->bExternalMp3Player);
	lpWavPlayerCmd->setEnabled(m_lpOpt->bExternalWavPlayer);

	connect(lpListenToCtcpSound,SIGNAL(toggled(bool)),lpPlayDefSound,SLOT(setEnabled(bool)));
	connect(lpListenToCtcpSound,SIGNAL(toggled(bool)),lpSendSoundRequest,SLOT(setEnabled(bool)));

	addTab(lpMsgTab,i18n("Messages"));
	addTab(lpDCCTab,i18n("DCC"));
//	addTab(lpNotTab,i18n("Notify"));
	addTab(lpTrnTab,i18n("Translation/URL"));
	addTab(lpMix3Tab,i18n("Sound"));
	addTab(lpMisTab,i18n("Misc 1"));
	addTab(lpMixTab,i18n("Misc 2"));
	addTab(lpMix4Tab,i18n("Misc 3"));
	setCancelButton();

	connect(this,SIGNAL(applyButtonPressed()),this,SLOT(applySlot()));

	QResizeEvent e(size(),size());
	resizeEvent(&e);
}


KviOptDialog::~KviOptDialog()
{
	delete lpMassDeopTime;
	delete lpMassOpTime;
	delete lpMassKickTime;
	delete lpMassBanTime;
	delete lpPublicFloodTime;
	delete lpUseFastSend;
	delete lpFSPacketsPerSec;
	delete lpFSPacketSize;
	delete lpMassDeopDeadline;
	delete lpMassOpDeadline;
	delete lpMassKickDeadline;
	delete lpMassBanDeadline;
	delete lpPublicFloodDeadline;
	delete lpAuPlayerCmd;
	delete lpMidPlayerCmd;
	delete lpMp3PlayerCmd;
	delete lpWavPlayerCmd;
	delete lpExternalAuPlayer;
	delete lpExternalMidPlayer;
	delete lpExternalMp3Player;
	delete lpExternalWavPlayer;
	delete lpListenFileRequest;
	delete lpSendSoundRequest;
	delete lpAutoCompletion;
	delete lpListenToCtcpSound;
	delete lpAutoJoinOnInvite;
	delete lpPlayDefSound;
	delete lpShowColorBox;
	delete lpTimestamp;
	delete lpAlignText;
	delete lpShowPixmaps;
	delete lpHighlightUrl;
	delete lpUrlColor;
	delete lpCaption;
	delete lpQuit;
	delete lpMotd;
	delete lpShowMotdOnOutDcc;
	delete lpShowMotdOnInDcc;
	delete lpBrowserCmd;
	delete lpBrowserOnUrl;
	delete lpUseNetscape;
	delete lpPrivNoticeToActive;
	delete lpPart;
	delete lpKick;
	delete lpAway;
	delete lpFinger;
	delete lpUserInfo;
	delete lpScript;
	delete lpIp;
	delete lpAutoRejoin;
	delete lpPrefixMsg;
	delete lpPrfx;
	delete lpPacket;
	delete lpTimeout;
	delete lpAutoClose;
	delete lpAutoChat;
	delete lpAutoSend;
	delete lpMaxFileRequests;
	delete lpAutoMinimize;
	delete lpIgnoreChat;
	delete lpIgnoreSend;
	delete lpChooseFile;	
	delete lpMaxCTCP;
	delete lpSecCTCP;
	delete lpInverseNick;
	delete lpUserList;
	delete lpUserTime;
	delete lpClone;
	delete lpCtcpRequestsToActive;
	delete lpIdentParsingOff;
	delete lpAutoLogChannels;
	delete lpAutoLogQueries;
	delete lpAutoLogChats;
	delete lpMinimizeQuery;
	delete lpBeepOnPrivmsg;
	delete lpBeepOnDCCRequest;
	delete lpBeepOnCTCPRequest;
//	delete lpNotify;
//	delete lpRem;
//	delete lpAdd;
//	delete lpBox;
//	delete lpEdit;
//	delete lpNotifyTime;
//	delete lpNotifyInActive;
	delete lpUseTran;
	delete lpTranFile;
	delete lpNotTranDCC;
	delete lpDCCTab;
	delete lpMisTab;
	delete lpMsgTab;
//	delete lpNotTab;
//	delete lpUrlTab;
	delete lpMixTab;
	delete lpMix3Tab;
	delete lpTrnTab;
}

//============ enableMotd ============//

void KviOptDialog::enableMotd(bool)
{
	_debug_entertrace("enableMotd");
	lpMotd->setEnabled(lpShowMotdOnInDcc->isChecked() || lpShowMotdOnOutDcc->isChecked());
	_debug_leavetrace("enableMotd");
}



//============ resizeEvent ============//

void KviOptDialog::resizeEvent(QResizeEvent *)
{
	_debug_entertrace("resizeEvent");
	setFixedSize(500,400);
	_debug_leavetrace("resizeEvent");
}


//============ addNick ============//
//
//void KviOptDialog::addNick()
//{
//	_debug_entertrace("addNick");
//	if(lpEdit->text()){
//		//check that we have enough space
//		uint cnt=lpBox->count();
//		int charcnt=0;
//		for(uint i=0;i<cnt;i++){
//			const char *szText=lpBox->text((int)i);
//			if(szText){
//				charcnt+=strlen(szText);
//				charcnt++;
//			}
//			if(!strcasecmp(lpEdit->text(),szText)){
//				KMsgBox::message(this,i18n("Notify list error"),i18n("This nick is already in the notify list.\n"));
//				return;
//			}
//		}
//		charcnt+=strlen(lpEdit->text());
//		if(charcnt>490){
//			KMsgBox::message(this,i18n("Notify list error"),
//					 i18n("Can not add another nick to the notify list.\n"
//					 "The ISON message is limited to 510 characters.\n"
//					 "Check the current notify list, are you sure that you\n"
//					 "really need all the nicks listed?"));
//			return;
//		}
//		if(strlen(lpEdit->text())>0){
//			lpBox->insertItem(lpEdit->text());
//			lpEdit->setText("");
//		}
//	}
//	_debug_leavetrace("addNick");
//}

//============ removeNick ============//
//
//void KviOptDialog::removeNick()
//{
//	_debug_entertrace("removeNick");
//	if(lpBox->currentItem() != -1){
//		lpBox->removeItem(lpBox->currentItem());
//	}
//	_debug_leavetrace("removeNick");
//}

//============ chatIgnore ============//

void KviOptDialog::chatIgnore(bool bIgnore)
{
	_debug_entertrace("chatIgnore");
	lpAutoChat->setEnabled(!bIgnore);
	_debug_leavetrace("chatIgnore");
}

//============ sendIgnore ============//

void KviOptDialog::sendIgnore(bool bIgnore)
{
	_debug_entertrace("sendIgnore");
	lpAutoSend->setEnabled(!bIgnore);
	_debug_leavetrace("sendIgnore");
}

//============ voiceIgnore ============//

void KviOptDialog::voiceIgnore(bool bIgnore)
{
	_debug_entertrace("voiceIgnore");
	lpAutoVoice->setEnabled(!bIgnore);
	_debug_leavetrace("voiceIgnore");
}

//============ chooseTranslationFile ============//

void KviOptDialog::chooseTranslationFile()
{
	_debug_entertrace("chooseTranslationFile");
	QString szHome(_macro_getKVircHomeDirectory("Translation"));
	QString szCmd=QString(_macro_getOpenFileName(i18n("Open translation map file..."),szHome.data(),0));
	if(!szCmd.isEmpty()){
		if(m_lpFrm->m_lpTranslator->setTranslationMap(szCmd.data())){
			m_lpOpt->szTranslationFile=szCmd.data();
			QString szText=i18n("Translation map file : ");
			szText+=m_lpOpt->szTranslationFile.data();
			lpTranFile->setText(szText.data());
			m_lpOpt->bUseTranslation=true;
		} else {
			lpUseTran->setChecked(false);
			m_lpOpt->bUseTranslation=false;
			m_lpOpt->szTranslationFile=i18n("[__none__]");
			QString szText=i18n("Translation map file : ");
			szText+=m_lpOpt->szTranslationFile.data();
			lpTranFile->setText(szText.data());
			lpTranFile->setEnabled(false);
			lpChooseFile->setEnabled(false);
		}
	}

	_debug_leavetrace("chooseTranslationFile");
}



void KviOptDialog::applySlot()
{
	_debug_entertrace("applySlot");
	m_lpOpt->szCaption=(lpCaption->text() ? lpCaption->text() : "");
	m_lpOpt->szQuitMsg=(lpQuit->text()    ? lpQuit->text()    : "");
	m_lpOpt->szPartMsg=(lpPart->text()    ? lpPart->text()    : "");
	m_lpOpt->szKickMsg=(lpKick->text()    ? lpKick->text()    : "");
	m_lpOpt->szFinger =(lpFinger->text()  ? lpFinger->text()  : "");
	m_lpOpt->szAwayMsg=(lpAway->text()    ? lpAway->text()    : "");
	m_lpOpt->szUserInfo=(lpUserInfo->text() ? lpUserInfo->text() : "");
	m_lpOpt->szScriptVer=(lpScript->text() ? lpScript->text() : "");
	m_lpOpt->szLocalIp=(lpIp->text()      ? lpIp->text()      : "127.0.0.1");
	m_lpOpt->szBrowserCmdLine=(lpBrowserCmd->text() ? lpBrowserCmd->text() : "kfmclient openUrl '%'");
	QString szPr=(lpPrfx->text()          ? lpPrfx->text()    : "@");
	if(!szPr.isEmpty())m_lpOpt->chPersonalCommandPrefix=szPr[0];
	m_lpOpt->iDCCCHATTimeout=lpTimeout->value();
	if(m_lpOpt->iDCCCHATTimeout<10)m_lpOpt->iDCCCHATTimeout=10;
	m_lpOpt->iDCCSendPacketSize=lpPacket->value();
	if(m_lpOpt->iDCCSendPacketSize<64)m_lpOpt->iDCCSendPacketSize=64;
	if(m_lpOpt->iDCCSendPacketSize>4096)m_lpOpt->iDCCSendPacketSize=4096;

	m_lpOpt->iTimerCTCP=lpSecCTCP->value();
	if(m_lpOpt->iTimerCTCP<0)m_lpOpt->iTimerCTCP=0;
	m_lpOpt->iMaxCTCP=lpMaxCTCP->value();
	if(m_lpOpt->iMaxCTCP<1)m_lpOpt->iMaxCTCP=1;

	m_lpOpt->iUserListUpdateTime=lpUserTime->value();
	if(m_lpOpt->iUserListUpdateTime<2)m_lpOpt->iUserListUpdateTime=2;
//	m_lpOpt->iNotifyTimer=lpNotifyTime->value();
//	if(m_lpOpt->iNotifyTimer<5)m_lpOpt->iNotifyTimer=5;

	m_lpOpt->iMaxFileRequests=lpMaxFileRequests->value();
	if((m_lpOpt->iMaxFileRequests<0)||(m_lpOpt->iMaxFileRequests>20))m_lpOpt->iMaxFileRequests=5;

	m_lpOpt->urlHighlightForeColor=(char)lpUrlColor->value();
	if((m_lpOpt->urlHighlightForeColor<0)||(m_lpOpt->urlHighlightForeColor>15))m_lpOpt->urlHighlightForeColor=12;

	m_lpOpt->massDeopDeadline=(Q_UINT32)lpMassDeopDeadline->value();
	m_lpOpt->massDeopTime=(Q_UINT32)lpMassDeopTime->value();
	m_lpOpt->massOpDeadline=(Q_UINT32)lpMassOpDeadline->value();
	m_lpOpt->massOpTime=(Q_UINT32)lpMassOpTime->value();
	m_lpOpt->massKickDeadline=(Q_UINT32)lpMassKickDeadline->value();
	m_lpOpt->massKickTime=(Q_UINT32)lpMassKickTime->value();
	m_lpOpt->massBanDeadline=(Q_UINT32)lpMassBanDeadline->value();
	m_lpOpt->massBanTime=(Q_UINT32)lpMassBanTime->value();
	m_lpOpt->publicFloodDeadline=(Q_UINT32)lpPublicFloodDeadline->value();
	m_lpOpt->publicFloodTime=(Q_UINT32)lpPublicFloodTime->value();

//	uint cnt=lpBox->count();
//	while(!m_lpOpt->lpNotifyList->isEmpty())m_lpOpt->lpNotifyList->removeLast();
//	if(cnt){
//		for(uint i=0;i<cnt;i++){
//			m_lpOpt->lpNotifyList->append(lpBox->text(i));
//		}
//	}
	if(m_lpOpt->bUseTranslation){
		if(m_lpOpt->szTranslationFile != i18n("[__none__]")){
			if(!m_lpFrm->m_lpTranslator->setTranslationMap(m_lpOpt->szTranslationFile.data())){
				m_lpOpt->szTranslationFile=i18n("[__none__]");
				m_lpOpt->bUseTranslation=false;
			}
		} else m_lpOpt->bUseTranslation=false;
	}
	while(!m_lpOpt->lpListDccMotd->isEmpty())m_lpOpt->lpListDccMotd->removeLast();
	int nLines=lpMotd->numLines();
	if(nLines>0){
		for(int i=0;i<nLines;i++){
			const char *szTextLine=lpMotd->textLine(i);
			if(szTextLine){
				QString szLine=szTextLine;
				if(!szLine.isEmpty()){
					int idx=szLine.find('\n');
					if(idx == -1){
						m_lpOpt->lpListDccMotd->append(szLine.data());
					} else {
						szLine.remove(idx,1);
						if(!szLine.isEmpty())m_lpOpt->lpListDccMotd->append(szLine.data());
					}
				}
			}
		}
	}
	long lastRate=(m_lpOpt->iFSPacketsPerSec * m_lpOpt->iFSPacketSize) / 1024;
	m_lpOpt->iFSPacketsPerSec=lpFSPacketsPerSec->currentItem()+1;
	if((m_lpOpt->iFSPacketsPerSec<1)||(m_lpOpt->iFSPacketsPerSec>20))m_lpOpt->iFSPacketsPerSec=2;
	int curFSSize=lpFSPacketSize->currentItem();
	switch(curFSSize){
		case 0: m_lpOpt->iFSPacketSize=64;   break;
		case 1: m_lpOpt->iFSPacketSize=128;  break;
		case 2: m_lpOpt->iFSPacketSize=256;  break;
		case 3: m_lpOpt->iFSPacketSize=512;  break;
		case 4: m_lpOpt->iFSPacketSize=768;  break;
		case 5: m_lpOpt->iFSPacketSize=1024; break;
		case 6: m_lpOpt->iFSPacketSize=1536; break;
		case 7: m_lpOpt->iFSPacketSize=2048; break;
		case 8: m_lpOpt->iFSPacketSize=2560; break;
		case 9: m_lpOpt->iFSPacketSize=3072; break;
		case 10:m_lpOpt->iFSPacketSize=4096; break;
		default:
			m_lpOpt->iFSPacketSize=512;
			break;
	}
	long newRate=(m_lpOpt->iFSPacketsPerSec * m_lpOpt->iFSPacketSize) / 1024;
	if(newRate != lastRate){
		if(newRate > 10){
			QString szWarning=i18n("You have selected ");
			QString szNewRate;
			QString szCpt;
			szNewRate.setNum(newRate);
			szWarning+=szNewRate.data();
			szWarning+=i18n(" Kb/sec. transfer rate for DCC Send.\n");
			if(newRate > 40){
				szWarning+=i18n("Did you know that this is a suicide?");
				szCpt=i18n("DCC Fast Suicide warning.");
			} else {
				szWarning+=i18n("Make sure that your connection and your hardware can support it.");
				szCpt=i18n("DCC Fast Send high rate warning.");
			}
			KMsgBox::message(this,szCpt.data(),szWarning.data());
		}
	}
	m_lpOpt->szAuPlayerCmd=(lpAuPlayerCmd->text() ? lpAuPlayerCmd->text() : "");
	m_lpOpt->szMidPlayerCmd=(lpMidPlayerCmd->text() ? lpMidPlayerCmd->text() : "");
	m_lpOpt->szMp3PlayerCmd=(lpMp3PlayerCmd->text() ? lpMp3PlayerCmd->text() : "");
	m_lpOpt->szWavPlayerCmd=(lpWavPlayerCmd->text() ? lpWavPlayerCmd->text() : "");

	if(m_lpOpt->szAuPlayerCmd.isEmpty())m_lpOpt->bExternalAuPlayer=false;
	if(m_lpOpt->szMidPlayerCmd.isEmpty())m_lpOpt->bExternalMidPlayer=false;
	if(m_lpOpt->szMp3PlayerCmd.isEmpty())m_lpOpt->bExternalMp3Player=false;
	if(m_lpOpt->szWavPlayerCmd.isEmpty())m_lpOpt->bExternalWavPlayer=false;


	accept();
	
	_debug_leavetrace("applySlot");
}

#include "m_kvi_optdlg.moc"

//
// $Log: kvi_optdlg.cpp,v $
// Revision 1.10  1998/10/06 14:42:39  pragma
// Tons of changes
//
// Revision 1.9  1998/10/01 00:54:47  pragma
// 'Ctcp requests to active window' option added
//
// Revision 1.8  1998/09/28 13:52:00  pragma
// Minor bugfixes
//
// Revision 1.7  1998/09/23 23:15:11  pragma
// Ignore list. Still needs testing.
// Added some ASSERT-Like macros to kvi_chan.cpp and kvi_listbox.cpp
// to discover a strange bug :
// Sometimes the a single nick on a random channel gets wrong username...
// Just like a hollow pointer...but still can't guess how to reproduce it.
// It happened only a couple of times...
//
// Revision 1.6  1998/09/23 12:41:46  pragma
// Another big commit.
// Added user list (Still have to fix ignore things)
// User list dialogs
// Some code rearrangements
// Minor bugfixes
//
// Revision 1.5  1998/09/20 20:23:22  fritz
// reorganized includes.
// More work on srvdlg - still not finished.
//
// Revision 1.4  1998/09/17 16:14:36  pragma
// Moving to handle mp3 , au and mid files by external players.
//
// Revision 1.3  1998/09/16 17:16:40  fritz
// Starting i18n.
//
// Revision 1.2  1998/09/16 16:13:16  pragma
// Moving to use a dynamic kvirc home directory.
// Big commit :)
//
//
