//   $Id: kvi_taskbar.cpp,v 1.3 1998/09/20 20:24:05 fritz Exp $
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1998 Szymon Stefanek (stefanek@tin.it)
//
//   This program is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Library General Public
//   License as published by the Free Software Foundation; either
//   version 2 of the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Library General Public License for more details.
//
//   You should have received a copy of the GNU Library General Public License
//   along with this program; see the file COPYING.  If not, write to
//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA 02111-1307, USA.
//

//#define _KVI_DEBUG_CLASS_NAME_ "KviTaskBar"

#include "kvi_defs.h"
#include "kvi_taskbar.h"
#include "kvi_debug.h"
#include "kvi_mdi.h"

#include <qtooltip.h>
#include <qbuttongroup.h>

//============ KviTaskBar ============//

KviTaskBar::KviTaskBar(KTopLevelWidget *lpFrame,KviMdiManager *lpMdiManager,const char *name) : KToolBar(lpFrame,name,28)
{
	_debug_entertrace("KviTaskBar");
	m_lpFrm=lpFrame;
	m_lpMdi=lpMdiManager;
	setFullWidth(TRUE);


	m_lpButtonGroup = new QButtonGroup(this);
	m_lpButtonGroup->setExclusive(true);

	m_lpBtnList=new QList<KviTaskBarButton>;
	m_lpBtnList->setAutoDelete(true);
	
	connect(m_lpButtonGroup,SIGNAL(clicked(int)),this,SLOT(slotButtonPressed(int)));

	m_iLastHeight=height();

	enableMoving(false);
	_debug_leavetrace("KviTaskBar");
}

//============ ~KviTaskBar ============//

KviTaskBar::~KviTaskBar()
{
	_debug_entertrace("~KviTaskBar");
	while(!m_lpBtnList->isEmpty()){
		m_lpButtonGroup->remove(m_lpBtnList->last());
		m_lpBtnList->removeLast();
	}
	delete m_lpBtnList;
	delete m_lpButtonGroup;
	_debug_leavetrace("~KviTaskBar");
}

//============ findButton ============//

KviTaskBarButton * KviTaskBar::findButton(int nID)
{
	_debug_checkpoint("findButton");
	KviTaskBarButton * lpB=0;
	for(lpB=m_lpBtnList->first();lpB;lpB=m_lpBtnList->next()){
		if(lpB->m_nID==nID)return lpB;
	}
	_debug_warning("findButton : Button not found!");
	return 0;
}

//============ changeButtonText ============//

void KviTaskBar::changeButtonText(int nID,const char *text)
{
	_debug_entertrace("changeButtonText");
	KviTaskBarButton * lpB=findButton(nID);
	if(lpB){
		QToolTip::remove(lpB);
		QToolTip::add(lpB,text);
		lpB->setText(text);
		lpB->repaint(false);
	} else _debug_warning("changeButtonText : Found no button with specified ID");
	_debug_leavetrace("changeButtonText");
}

//============ addButton ============//

KviTaskBarButton * KviTaskBar::addButton(int nID,const char *text,const char *szIconName,bool bNeedProgress)
{
	_debug_entertrace("addButton");
	KviTaskBarButton *lpPb=new KviTaskBarButton(text,m_lpButtonGroup,szIconName,nID,bNeedProgress);
	lpPb->setToggleButton(true);
	lpPb->installEventFilter(this);
	lpPb->setFocusProxy(m_lpMdi);
	QToolTip::add(lpPb,text);
	lpPb->show();
	m_lpButtonGroup->insert(lpPb,nID);
	m_lpBtnList->append(lpPb);
	layoutButtons();
	setActiveButton(nID);
	_debug_leavetrace("addButton");
	return lpPb;
}

//============ unpressAllButtons ============//

void KviTaskBar::unpressAllButtons(){
	_debug_entertrace("unpressAllButtons");
	KviTaskBarButton * lpB=0;
	for(lpB=m_lpBtnList->first();lpB;lpB=m_lpBtnList->next()){
		if(lpB->isOn())lpB->setOn(false);
	}
	_debug_leavetrace("unpressAllButtons");
}

//============ highlightButton ============//

void KviTaskBar::highlightButton(int nID)
{
	_debug_entertrace("highlightButton");
	KviTaskBarButton * lpB=findButton(nID);
	if(lpB)lpB->Highlight(true);
	//else debug("highlightButton : Found no button with ID=%d",nID);
	_debug_leavetrace("highlightButton");
}

//============ setActiveButton ============//

void KviTaskBar::setActiveButton(int nID)
{
	_debug_entertrace("setActiveButton");
//	debug("Called for window with ID = %d",nID);
	KviTaskBarButton * lpB=0;
	for(lpB=m_lpBtnList->first();lpB;lpB=m_lpBtnList->next()){
		if(lpB->m_nID==nID)lpB->setOn(true);
		else {
			if(lpB->isOn())lpB->setOn(false);
		}
	}
	_debug_leavetrace("setActiveButton");
}

//============ eventFilter ============//

bool KviTaskBar::eventFilter( QObject *ob, QEvent *e ){
	_debug_entertrace("eventFilter");
	if(e->type()==Event_MouseButtonPress){
		if(((QMouseEvent *)e)->button() & RightButton){
				QPoint pnt=((QMouseEvent *)e)->pos();
				emit taskBarPopupRequest(((KviTaskBarButton *)ob)->mapToGlobal(pnt),((KviTaskBarButton *)ob)->m_nID);
		} //else emit itemActivated(((KviTaskBarButton *)ob)->m_nID);
	}
	_debug_leavetrace("eventFilter");
	return false;
}

//============ slotButtonPressed ============//
//#warning "To be removed"
void KviTaskBar::slotButtonPressed(int nId)
{
	_debug_entertrace("slotButtonPressed");
	emit itemActivated(nId);
	_debug_leavetrace("slotButtonpressed");
}

//============ removeButton ============//

void KviTaskBar::removeButton(int m_nID)
{
	_debug_entertrace("removeButton");
	KviTaskBarButton *lpPb=(KviTaskBarButton *)m_lpButtonGroup->find(m_nID);
	if(!lpPb)_debug_warning("removeButton : invalid button ID");
	else {
		m_lpButtonGroup->remove(lpPb);
		if(!m_lpBtnList->remove(lpPb))_debug_warning("removeButton :the button can not be foud in the list!");
		layoutButtons();
	}
	_debug_leavetrace("removeButton");
}

//============ layoutButtons ============//

void KviTaskBar::layoutButtons()
{
	_debug_entertrace("layoutButtons");
	uint btnCnt=m_lpBtnList->count();
	if(!btnCnt)return;
	int curWidth=width()-(2*KVI_TASKBAR_SIDE_BORDER);
	if(curWidth<0)curWidth=0;
	QFontMetrics fm=(m_lpBtnList->isEmpty() ? fontMetrics() : m_lpBtnList->first()->fontMetrics());
	int btnHeight=fm.lineSpacing()+10;
	if(btnHeight<20)btnHeight=20;
	m_lpButtonGroup->setGeometry(KVI_TASKBAR_SIDE_BORDER,KVI_TASKBAR_TOP_BORDER,curWidth,btnHeight);
	KviTaskBarButton *lpB=0;
	uint aCnt=0;
	int btnWidth=(curWidth)/btnCnt;
	for(lpB=m_lpBtnList->first();lpB;lpB=m_lpBtnList->next()){
		if((aCnt+1)==btnCnt)lpB->setGeometry(aCnt*btnWidth,0,curWidth-(aCnt*btnWidth),btnHeight);
		else lpB->setGeometry(aCnt*btnWidth,0,btnWidth,btnHeight);
		aCnt++;	
	}
	_debug_leavetrace("layoutButtons");
}

//============ setButtonProgress ============//

void KviTaskBar::setButtonProgress(int nID,int iProgress)
{
	_debug_entertrace("setButtonProgress");
	KviTaskBarButton *lpB=findButton(nID);
	if(lpB){
//		debug("setting progress of btn %d : %d",nID,iProgress);
		lpB->m_iProgressState=iProgress;
		lpB->repaint(false);
	} else _debug_warning("setButtonProgress : Found no button with specified ID");
	_debug_leavetrace("setButtonProgress");
}

//============ resizeEvent ============//

void KviTaskBar::resizeEvent(QResizeEvent *)
{
	_debug_entertrace("resizeEvent");
	layoutButtons();
	_debug_leavetrace("resizeEvent");
}

//============ focusInEvent ============//

void KviTaskBar::focusInEvent(QFocusEvent *)
{
	_debug_entertrace("focusInEvent");
	m_lpMdi->setActiveWindow();
	m_lpMdi->setFocus();
	_debug_leavetrace("focusInEvent");
}

#include "m_kvi_taskbar.moc"

//
// $Log: kvi_taskbar.cpp,v $
// Revision 1.3  1998/09/20 20:24:05  fritz
// reorganized includes.
// More work on srvdlg - still not finished.
//
// Revision 1.2  1998/09/15 13:19:38  pragma
// Taskbar buttons progress view fix.
//
//
