//   $Id: kvi_tskbtn.cpp,v 1.3 1998/09/20 20:24:13 fritz Exp $
//
//   This file is part of the KVIrc+ irc client distribution
//   Copyright (C) 1998 Szymon Stefanek (stefanek@tin.it)
//
//   This program is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Library General Public
//   License as published by the Free Software Foundation; either
//   version 2 of the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   Library General Public License for more details.
//
//   You should have received a copy of the GNU Library General Public License
//   along with this program; see the file COPYING.  If not, write to
//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA 02111-1307, USA.
//

//#define _KVI_DEBUG_CLASS_NAME_ "KviTaskBarButton"

#include "kvi_macros.h"
#include "kvi_tskbtn.h"
#include "kvi_debug.h"
#include "kvi_app.h"

#include <kiconloader.h>

#include <qpainter.h>
#include <qdrawutil.h>

KviTaskBarButton::KviTaskBarButton(const char *text,QWidget *parent,const char *iconName,int nID,bool bProgress) : QPushButton(text,parent){
	_debug_entertrace("KviTaskBarButton");
	m_nID=nID;
	m_bHighlited=false;
	m_IconPixmap = _macro_kviIconLoader->loadIcon(iconName);
	installEventFilter(this);
	m_iProgressState=0;
	m_bProgress=bProgress;
	_debug_leavetrace("KviTaskBarButton");
}

KviTaskBarButton::~KviTaskBarButton()
{
	_debug_entertrace("~KviTaskBarButton");
	_debug_leavetrace("~KviTaskBarButton");
}

//============ eventFilter ============//

bool KviTaskBarButton::eventFilter(QObject *,QEvent *ev)
{
	_debug_entertrace("eventFilter");
	if(ev->type()==Event_MouseButtonRelease)return isOn();
	_debug_leavetrace("eventFilter");
	return false;
}


void KviTaskBarButton::Highlight(bool high)
{
	_debug_entertrace("Highlight");
	if(!isOn()){
		if(m_bHighlited != high){
			m_bHighlited=high;
			repaint(false);
		}
	}
	_debug_leavetrace("Highlight");
}

void KviTaskBarButton::drawButtonLabel(QPainter * paint){
	if(!m_IconPixmap.isNull())paint->drawPixmap(3,3,m_IconPixmap);
	if(isOn()){
		//paint->setPen(black);
		m_bHighlited=false;
		QFont the_font=paint->font();
		the_font.setBold(true);
		paint->setFont(the_font);
	} else {
		if(m_bHighlited)paint->setPen(red);
	}
	paint->drawText(25,0,width()-30,height(),AlignVCenter | AlignLeft,text());
}

void KviTaskBarButton::drawButton(QPainter *paint){
	int w,x,y,h;
	rect().coords(&x,&y,&w,&h);
	if(!(w && h))return;
	QPixmap *theBuffer=new QPixmap(w,h);
	register QPainter *p = new QPainter();
	p->begin(theBuffer);
    QColorGroup g  = colorGroup();
    p->setPen( g.foreground() );
	QBrush theBrush(g.background());
    p->setBrush(theBrush);
	qDrawShadePanel( p, 0, 0, w, h, g, isOn(),1 ,&theBrush);
	if(m_bProgress){
		int wdth=(((width()-28)*m_iProgressState)/100);
//		debug("painting progress %d",m_iProgressState);
		p->setPen(QApplication::winStyleHighlightColor());
		p->drawRect( 25,3,w-28,h-5);
		p->fillRect( 25,3,wdth,h-5,QApplication::winStyleHighlightColor());
	}
	p->setPen(g.foreground());
    p->setBrush( NoBrush );
    drawButtonLabel( p );
	paint->drawPixmap(x,y,*theBuffer);
	p->end();
	delete theBuffer;	
}

#include "m_kvi_tskbtn.moc"

//
// $Log: kvi_tskbtn.cpp,v $
// Revision 1.3  1998/09/20 20:24:13  fritz
// reorganized includes.
// More work on srvdlg - still not finished.
//
// Revision 1.2  1998/09/15 13:19:40  pragma
// Taskbar buttons progress view fix.
//
//
